@@ -4,18 +4,16 @@
  *   SPDX-License-Identifier: GPL-2.0-or-later
  */
 
-#ifndef PLUGINS_VIRTUAL_DESKTOP_SWITCH_PLUGIN_H
-#define PLUGINS_VIRTUAL_DESKTOP_SWITCH_PLUGIN_H
+#pragma once
 
 #include <Plugin.h>
 
 class VirtualDesktopSwitchPlugin : public Plugin
 {
     Q_OBJECT
-    // Q_PLUGIN_METADATA(IID "org.kde.ActivityManager.plugins.virtualdesktopswitch")
 
 public:
-    explicit VirtualDesktopSwitchPlugin(QObject *parent = nullptr, const QVariantList &args = QVariantList());
+    explicit VirtualDesktopSwitchPlugin(QObject *parent);
     ~VirtualDesktopSwitchPlugin() override;
 
     bool init(QHash<QString, QObject *> &modules) override;
@@ -28,5 +26,3 @@ private:
     QString m_currentActivity;
     QObject *m_activitiesService;
 };
-
-#endif // PLUGINS_VIRTUAL_DESKTOP_SWITCH_PLUGIN_H
